R/get-panther.R
getPantherCollection.RdThis is a convience function that orchestrates the PANTHER.db package to return GeneSetDb objects for either pathway or GOslim information for human or mouse.
A BiocSet of panther pathways
Note that for some reason the PANTHER.db package needs to be
installed in a user-writable package location for this to work properly.
If you see an error like "Error in resqlite_send_query ... attempt to
write a readonly database", this is the problem. Please install another
version of the PANTHER.db package in a user-writable directory using
BiocManager::install().
getPantherGeneSetDb(): returns a GeneSetDb
GO Slims are "cut down" versions of the GO ontology that contain a subset of the terms in the whole GO.
PANTHER provides their own set of GO slims, although it's not clear how often these get updated.
# \donttest{
# this requires you have the PANTHER.db package installed via BiocManager
bsc.panther <- getPantherCollection(species = "human")
#> Error in getPantherGeneSetDb(type, species): org.Hs.eg.db bioconductor package required for this species query
#>
#> Warning: download failed
#> web resource path: ‘https://annotationhub.bioconductor.org/fetch/120820’
#> local file path: ‘/github/home/.cache/R/AnnotationHub/1d6754deb882_120820’
#> reason: Failed to perform HTTP request.
#> Caused by error in `curl::curl_fetch_disk()`:
#> ! Timeout was reached [mghp.osn.xsede.org]:
#> SSL connection timeout
#> Warning: bfcadd() failed; resource removed
#> rid: BFC3
#> fpath: ‘https://annotationhub.bioconductor.org/fetch/120820’
#> reason: download failed
#> Warning: download failed
#> hub path: ‘https://annotationhub.bioconductor.org/fetch/120820’
#> cache resource: ‘AH114074 : 120820’
#> reason: bfcadd() failed; see warnings()
#> Error loading resource.
#> attempting to re-download
#> Warning: download failed
#> web resource path: ‘https://annotationhub.bioconductor.org/fetch/120820’
#> local file path: ‘/github/home/.cache/R/AnnotationHub/1d67a0c5589_120820’
#> reason: Failed to perform HTTP request.
#> Caused by error in `curl::curl_fetch_disk()`:
#> ! Timeout was reached [mghp.osn.xsede.org]:
#> SSL connection timeout
#> Warning: bfcadd() failed; resource removed
#> rid: BFC4
#> fpath: ‘https://annotationhub.bioconductor.org/fetch/120820’
#> reason: download failed
#> Warning: download failed
#> hub path: ‘https://annotationhub.bioconductor.org/fetch/120820’
#> cache resource: ‘AH114074 : 120820’
#> reason: bfcadd() failed; see warnings()
#> Warning: .onUnload failed in unloadNamespace() for 'PANTHER.db', details:
#> call: NULL
#> error: failed to load resource
#> name: AH114074
#> title: PANTHER.db database
#> reason: 1 resources failed to download
# }